"
" insert_cancel.vim: Cancel the current insert operation by undoing the last
" change upon insert exit, if we made a change; intended for remapping
" insert-mode Ctrl-C.
"
" Author: Tom Ryder <tom@sanctum.geek.nz>
" License: Same as Vim itself
"
if exists('g:loaded_insert_cancel') || &compatible
  finish
endif
if v:version < 600
  finish
endif
let g:loaded_insert_cancel = 1

" InsertEnter is only available from Vim 7
if has('autocmd') && v:version > 700
  augroup insert_cancel
    autocmd!
    autocmd InsertEnter *
          let s:changenr = changenr()
  augroup END
endif

" Try to figure out whether we made a change to undo, undo it if so
function! s:InsertCancel()
  if &modified && (!exists('s:changenr') || changenr() > s:changenr)
    silent undo
  endif
endfunction

" Provide plugin mapping
inoremap <silent> <Plug>InsertCancel
      \ <C-C>:<C-U>call <SID>InsertCancel()<CR>
